@@ -567,29 +567,21 @@ class Video(Scene):
     def program(self):
         return self.attributes["program_name"]
 
-    def objectdetection(self, frame=1):
+    def object_detection(self, frame=1):
         """Run an object detector on a given frame of video.  It is more efficient to construct an ObjectDetector() object once and reuse it."""
         from pycollector.detection import ObjectDetector
-
         return ObjectDetector()(self.frame(frame))
 
-    def facedetection(self, frame=1):
+    def face_detection(self, frame=1):
         """Run face detection on a given frame of video.  It is more efficient to construct a FaceDetector() object once and reuse it."""
         from pycollector.detection import FaceDetector
-
         return FaceDetector()(self.frame(frame))
 
+    def faces(self, frame=1):
+        """Alias for face_detection"""
+        return self.face_detection(frame=frame)
 
-def search():
-    import pycollector.project
-
-    return pycollector.project.Project(since="2020-09-01")
-
-
+    
 def last(n=1, program=None):
     import pycollector.project
-
-    if program:
-        return pycollector.project.Project(program_id=program, since="2020-09-01", last=n).last(n)
-    else:
-        return pycollector.project.Project(since="2020-09-01", last=n).last(n)
+    return pycollector.project.Project(program=program, since="2020-09-01", last=n).last(n)
